@@ -1,15 +1,5 @@
 package App::Ack::Filter::Is;
 
-=head1 NAME
-
-App::Ack::Filter::Is
-
-=head1 DESCRIPTION
-
-Filters based on exact filename match.
-
-=cut
-
 use strict;
 use warnings;
 use base 'App::Ack::Filter';
