@@ -24,7 +24,7 @@ sub check_message {
 
 sub prep_environment {
     my @ack_args   = qw( ACK_OPTIONS ACKRC ACK_PAGER HOME ACK_COLOR_MATCH ACK_COLOR_FILENAME ACK_COLOR_LINE );
-    my @taint_args = qw( PATH CDPATH IFS );
+    my @taint_args = qw( PATH CDPATH IFS ENV );
     delete @ENV{ @ack_args, @taint_args };
 
     if ( is_windows() ) {
@@ -43,7 +43,7 @@ sub is_windows {
 }
 
 sub is_cygwin {
-    return $^O eq 'cygwin';
+    return ($^O eq 'cygwin' || $^O eq 'msys');
 }
 
 sub is_empty_array {
@@ -328,7 +328,7 @@ sub run_cmd {
 
     my ($sig,$core,$rc) = (($? & 127),  ($? & 128) , ($? >> 8));
     $ack_return_code = $rc;
-    ## XXX what do do with $core or $sig?
+    ## XXX what to do with $core or $sig?
 
     chomp @stdout;
     chomp @stderr;
